@@ -10,7 +10,11 @@ from calendarevents.model import DBSession
 
 from tgext.pluggable import plug_redirect
 
-from repoze.what import predicates
+try:
+    from tg import predicates
+except ImportError:
+    from repoze.what import predicates
+
 from calendarevents.lib.forms import new_calendar_form
 
 class CalendarController(TGController):
@@ -47,4 +51,4 @@ class CalendarController(TGController):
         model.DBSession.add(new_calendar)
         model.DBSession.flush()
         flash(_('Calendar successfully added'))
-        return plug_redirect('calendarevents', '/calendar/%s' % new_calendar.uid)
\ No newline at end of file
+        return plug_redirect('calendarevents', '/calendar/%s' % new_calendar.uid)
